import request from '@/utils/request'

// 查询班结管理列表
export function listStructure(query) {
  return request({
    url: '/station/structure/list',
    method: 'get',
    params: query
  })
}

export function listPersonnelStructure(query) {
  return request({
    url: '/station/structure/listPersonnelStructure',
    method: 'get',
    params: query
  })
}
export function listPersonnelPayStructure(query) {
  return request({
    url: '/station/structure/listPersonnelPayStructure',
    method: 'get',
    params: query
  })
}
export function listClass(query) {
  return request({
    url: '/station/structure/listClass',
    method: 'get',
    params: query
  })
}

export function listOilStructure(query) {
  return request({
    url: '/station/structure/listOilStructure',
    method: 'get',
    params: query
  })
}

// 查询油站信息列表
export function stationinfo() {
  return request({
    url: '/station/info/selectStationInfo',
    method: 'get'
  })
}
// 查询班结管理详细
export function getStructure(id) {
  return request({
    url: '/station/structure/' + id,
    method: 'get'
  })
}

// 新增班结管理
export function addStructure(data) {
  return request({
    url: '/station/structure',
    method: 'post',
    data: data
  })
}

// 修改班结管理
export function updateStructure(data) {
  return request({
    url: '/station/structure',
    method: 'put',
    data: data
  })
}

// 删除班结管理
export function delStructure(id) {
  return request({
    url: '/station/structure/' + id,
    method: 'delete'
  })
}

// 导出班结管理
export function exportStructure(query) {
  return request({
    url: '/station/structure/export',
    method: 'get',
    params: query
  })
}
//
export function getAgeClassStructure(query) {
  return request({
    url: '/station/structure/getAgeClassStructure',
    method: 'get',
    params: query
  })
}
export function getPayOrderInfoMin(query) {
  return request({
    url: '/station/order/getPayOrderInfoMin',
    method: 'get',
    params: query
  })
}
//初始化数据班结数据，根据员工汇总
export function selectPersonnelStructure(query) {
  return request({
    url: '/station/structure/selectPersonnelStructure',
    method: 'get',
    params: query
  })
}
//初始化数据班结数据，根据油品汇总
export function selectOilStructure(query) {
  return request({
    url: '/station/structure/selectOilStructure',
    method: 'get',
    params: query
  })
}
//初始化数据班结数据，根据员工/支付方式汇总
export function selectPersonnelPayStructure(query) {
  return request({
    url: '/station/structure/selectPersonnelPayStructure',
    method: 'get',
    params: query
  })
}
